@@ -1,4 +1,4 @@
-# Copyright 2020 Michael Thies <mail@mhthies.de>
+# Copyright 2020-2021 Michael Thies <mail@mhthies.de>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
@@ -8,11 +8,12 @@
 # Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an
 # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 # specific language governing permissions and limitations under the License.
-
+import abc
 import logging
 import math
-from typing import NamedTuple, Union, overload
+from typing import NamedTuple, Union, overload, Generic
 
+from shc.base import T
 from shc.conversion import register_converter, get_converter
 
 logger = logging.getLogger(__name__)
@@ -106,6 +107,54 @@ class AngleUInt8(int):
     pass
 
 
+class Balance(float):
+    """
+    A balance between to extreme positions, e.g. left-right, front-rear, channel 1-channel 2, etc., represented as a
+    floating point number between -1.0 and 1.0. Thus, 0.0 represents the "center"/"balanced"/"normal" value.
+
+    -1.0 typically means:
+    - left (audio balance)
+    - front (surround audio balance)
+    - no LFE (surround audio balance)
+    """
+    pass
+
+
+register_converter(RangeFloat1, Balance, lambda v: Balance(v * 2 - 1))
+register_converter(Balance, RangeFloat1, lambda v: RangeFloat1(v / 2 + 0.5))
+
+
+class AbstractStep(Generic[T], metaclass=abc.ABCMeta):
+    """
+    Abstract base class for all difference/step types, that represent a step within an associated range type
+    """
+    @abc.abstractmethod
+    def apply_to(self, value: T) -> T:
+        """
+        Apply this step to a given value of the associated range type
+
+        :param value: The old value
+        :return: The new value, when this step is applied to the old value
+        """
+        pass
+
+
+class FadeStep(float, AbstractStep[RangeFloat1]):
+    """
+    A dimmer or fader change step in the range -1.0 to 1.0. It can be applied to a :class:`RangeFloat1` adding it to the
+    step to the current value and clipping the result to the range 0..1.0.
+
+    See :class:`shc.misc.FadeStepAdapter` to do this to SHC.
+    """
+    pass
+
+    def apply_to(self, value: RangeFloat1) -> RangeFloat1:
+        return RangeFloat1(min(1.0, max(0.0, value + self)))
+
+
+register_converter(float, FadeStep, lambda v: FadeStep(min(1.0, max(-1.0, v))))
+
+
 class RGBUInt8(NamedTuple):
     """
     A 24bit color in RGB colorspace, composed of three :class:`RangeUInt8` values `red`, `green` and `blue`
