@@ -17,7 +17,7 @@ import logging
 import time
 from typing import List, Any, Dict, Deque, Generic, Union, Type, TypeVar, Tuple, cast, Optional
 
-from paho.mqtt.client import MQTTMessage  # type: ignore
+from paho.mqtt.client import MQTTMessage
 
 from ..base import Writable, Subscribable, T, Readable
 from .mqtt import MQTTClientInterface
@@ -617,7 +617,7 @@ class TasmotaOnlineConnector(Readable[bool], Subscribable[bool]):
 
     def __init__(self):
         super().__init__()
-        self.value = None
+        self.value = False
 
     def _update_from_mqtt(self, msg: MQTTMessage) -> None:
         self.value = msg.payload == b'Online'
